@@ -8,7 +8,7 @@ use Capture::Tiny qw( capture );
 use Carp ();
 
 # ABSTRACT: Alien::Build installer code for ExtUtils::MakeMaker
-our $VERSION = '1.98'; # VERSION
+our $VERSION = '2.26'; # VERSION
 
 
 sub new
@@ -254,7 +254,11 @@ sub mm_install
     $mm->SUPER::install(@rest);
   };
 
-  "install :: alien_clean_install\n\n$section";
+  return
+      ".NOTPARALLEL : \n\n"
+    . ".NO_PARALLEL : \n\n"
+    . "install :: alien_clean_install\n\n"
+    . $section;
 }
 
 sub import
@@ -346,6 +350,8 @@ sub import
           $install_files_pm->parent->mkpath;
           $install_files_pm->spew(
             "package ${mod}::Install::Files;\n",
+            "use strict;\n",
+            "use warnings;\n",
             "require ${mod};\n",
             "sub Inline { shift; ${mod}->Inline(\@_) }\n",
             "1;\n",
@@ -407,7 +413,7 @@ Alien::Build::MM - Alien::Build installer code for ExtUtils::MakeMaker
 
 =head1 VERSION
 
-version 1.98
+version 2.26
 
 =head1 SYNOPSIS
 
